==> deepin-calculator_5.7.12.orig.tar.gz: deepin-calculator-5.7.12/translations/deepin-calculator_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>بارلىق ساقلىغۇچنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>تارىخىي خاتىرىنى ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>ھەممىنى تاللاش</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>ئەسلىگە كەلتۈرۈش</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>كېسىش</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چاپلاش</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>ھېسابلىغۇچ</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>ئۆلچەم</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>ئىلمىي</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ھالەت</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>ئۈستەل يۈزى ھېسابلىغۇچنى ئىشلىتىش ئاسان ، ئۆلچەملىك ، ئىلمىي ۋە پروگراممېر ھالىتىنى قوللايدۇ.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>پروگراممېر</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>ساقلانما تۈرلىرىنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>بارلىق ساقلىغۇچنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>ساقلانمىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>ساقلانما تۈرى قوشۇش</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>ئىچكى ساقلىغۇچقا قوشۇلدى</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>ئىچكى ساقلىغۇچ تۈرىدىن ئازايتىش</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>ئىچكى ساقلىغۇچ ئازايدى</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>ئىچكى ساقلىغۇچقا ساقلاش</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ئىچكى ساقلىغۇچ</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>خاتېرە تۈرلىرىنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>خاتېرە تۈرى قوشۇش</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>ئىچكى ساقلىغۇچ تۈرىدىن ئازايتىش</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>ساقلىغۇچىتا ھېچنىمە يوق</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>ئارفىمېتكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>لوگىكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>ئايلانما يۆتكىلىش</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ئايلانما يۆتكىلىش ئارقىلىق ئايلىنىش</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>ئارفىمېتكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>لوگىكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>ئايلانما يۆتكىلىش</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ئايلانما يۆتكىلىش ئارقىلىق ئايلىنىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>ھېسابلىغۇچ</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>تارىخىي خاتىرە</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ئىچكى ساقلىغۇچ</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>تارىخىي خاتىرە يوق</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.4.orig.tar.gz: deepin-calculator-6.5.4/translations/deepin-calculator_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>بارلىق ساقلىغۇچنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>تارىخىي خاتىرىنى ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>ھەممىنى تاللاش</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo</source>
        <translation>ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>ئەسلىگە كەلتۈرۈش</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>كېسىش</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>چاپلاش</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>ھېسابلىغۇچ</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>ئۆلچەم</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>ئىلمىي</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ھالەت</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>ئۈستەل يۈزى ھېسابلىغۇچنى ئىشلىتىش ئاسان ، ئۆلچەملىك ، ئىلمىي ۋە پروگراممېر ھالىتىنى قوللايدۇ.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>پروگراممېر</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>ساقلانما تۈرلىرىنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>بارلىق ساقلىغۇچنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>ساقلانمىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>ساقلانما تۈرى قوشۇش</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>ئىچكى ساقلىغۇچقا قوشۇلدى</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>ئىچكى ساقلىغۇچ تۈرىدىن ئازايتىش</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>ئىچكى ساقلىغۇچ ئازايدى</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>ئىچكى ساقلىغۇچقا ساقلاش</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ئىچكى ساقلىغۇچ</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>خاتېرە تۈرلىرىنى ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>خاتېرە تۈرى قوشۇش</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>ئىچكى ساقلىغۇچ تۈرىدىن ئازايتىش</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>ساقلىغۇچىتا ھېچنىمە يوق</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>ئارفىمېتكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>لوگىكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>ئايلانما يۆتكىلىش</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ئايلانما يۆتكىلىش ئارقىلىق ئايلىنىش</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>ئارفىمېتكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>لوگىكىلىق يۆتكىلىش</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>ئايلانما يۆتكىلىش</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>ئايلانما يۆتكىلىش ئارقىلىق ئايلىنىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>ھېسابلىغۇچ</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>تارىخىي خاتىرە</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>ئىچكى ساقلىغۇچ</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>ئىپادىلەش خاتا</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>تارىخىي خاتىرە يوق</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
</TS>
